@@ -8,7 +8,7 @@
 #include "newprogramwindow.h"
 #include "settingswindow.h"
 #include "xml.h"
-//#include "athread.h"
+#include "athread.h"
 #include "playsound.h"
 #include "weightdialog.h"
 #include "newingredientwindow.h"
@@ -28,7 +28,7 @@ private:
     NewProgramWindow *npw;
     XML *xml;
     HistoryWindow *hw;
-    //aThread *myThread;
+    aThread *myThread;
     PlaySound *sound;
     WeightDialog *wd;
 
@@ -81,7 +81,8 @@ private slots:
     void showNewExercise();
     void showNewProgram();
     void update();
-    void checkAcc();//QString x);
+    void checkAcc(QString x);
+    void shaked();
     void stopVibrate();
     void skipWait();
     void showNewIngredient();
